DraggableWidget class

A Flutter widget class DraggableWidget for displaying and managing draggable stickers.

Inheritance

Constructors

DraggableWidget({Key? key, required Widget child, required Color borderColor, required Color iconColor, required bool showDone, required bool showClose, required bool showFlip, required bool showStack, required bool showLock, required bool showAllBorders, required bool shouldMove, required bool shouldRotate, required bool shouldScale, required double minScale, required double maxScale, required dynamic onBorder(Key?), required dynamic onDelete(Key?), required dynamic onLayer(Key?)})
Constructor to initialize the widget's properties.

Properties

borderColor Color
getter/setter pair
child Widget
Properties to customize the appearance and behavior of the widget.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iconColor Color
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxScale double
getter/setter pair
minScale double
getter/setter pair
notifier ValueNotifier<Matrix4>
Notifiers for updating the widget when changes occur.
final
onBorder ↔ dynamic Function(Key?)
Callback functions for various widget interactions.
getter/setter pair
onDelete ↔ dynamic Function(Key?)
getter/setter pair
onLayer ↔ dynamic Function(Key?)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldMove bool
getter/setter pair
shouldRotate bool
getter/setter pair
shouldScale bool
getter/setter pair
showAllBorders bool
getter/setter pair
showClose bool
getter/setter pair
showDone bool
getter/setter pair
showFlip bool
getter/setter pair
showLock bool
getter/setter pair
showStack bool
getter/setter pair
updater ValueNotifier<bool>
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showBorder(bool showBorder) → dynamic
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateWidget(Widget child) → dynamic

Operators

operator ==(Object other) bool
The equality operator.
inherited