LindiController class
A Dart class LindiController extending ChangeNotifier, used for managing a list of draggable widgets and their properties.
- Inheritance
-
- Object
- ChangeNotifier
- LindiController
Constructors
- LindiController({Color borderColor = Colors.blue, Color iconColor = Colors.white, bool showDone = true, bool showClose = true, bool showFlip = true, bool showStack = true, bool showLock = true, bool showAllBorders = true, bool shouldMove = true, bool shouldRotate = true, bool shouldScale = true, double minScale = 0.5, double maxScale = 4})
- Constructor to initialize properties with default values.
Properties
- borderColor ↔ Color
-
Color of the border
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- iconColor ↔ Color
-
Color of the icons
getter/setter pair
- maxScale ↔ double
-
Widget maximum scale
getter/setter pair
- minScale ↔ double
-
Widget minimum scale
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedIndex
↔ IndexStream<
int> -
Stream to listen selected index
getter/setter pair
- shouldMove ↔ bool
-
Should the widget move
getter/setter pair
- shouldRotate ↔ bool
-
Should the widget rotate
getter/setter pair
- shouldScale ↔ bool
-
Should the widget scale
getter/setter pair
- showAllBorders ↔ bool
-
Show All Buttons and Border
getter/setter pair
- showClose ↔ bool
-
Show the close button
getter/setter pair
- showDone ↔ bool
-
Show the done button
getter/setter pair
- showFlip ↔ bool
-
Show the flip button
getter/setter pair
- showLock ↔ bool
-
Show the lock button
getter/setter pair
- showStack ↔ bool
-
Show the stack button
getter/setter pair
-
widgets
↔ List<
DraggableWidget> -
List to store draggable widgets.
getter/setter pair
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
addWidget(
Widget widget) → dynamic -
clearAllBorders(
) → dynamic -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
saveAsUint8List(
) → Future< Uint8List?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited